@@ -11,16 +11,16 @@
 
 // IMPORTANT - default colors should be in hex for compatibility
 exports.defaults = [
-    '#0d94f6',  // muted blue
-    '#ff8500',  // safety orange
-    '#2ca02c',  // cooked asparagus green
-    '#f7412c',  // brick red
-    '#9467bd',  // muted purple
-    '#8c564b',  // chestnut brown
-    '#ffb2b0',  // raspberry yogurt pink
-    '#7f7f7f',  // middle gray
-    '#42d99a',  // curry yellow-green
-    '#2980b9'   // blue-teal
+    '#2BC9E2',  // safety orange
+    '#FAA654',  // cooked asparagus green
+    '#5DCB7E',  // brick red
+    '#FFE06E',  // muted purple
+    '#0D94F6',  // chestnut brown
+    '#42D99A',  // middle gray
+    '#BDBF1D',  // curry yellow-green
+    '#FF8500',   // blue-teal
+    '#F77373',  // muted blue
+    '#FFB2B0'  // raspberry yogurt pink
 ];
 
 exports.defaultLine = '#444';
