@@ -623,11 +623,10 @@ function computeTextDimensions(g, gd) {
 
 
         var textValue = g.select('.legendvalue');
-        var textValueNode = text.node();
+        var textValueNode = textValue.node();
         var valueWidth = 50;
-
         svgTextUtils.positionText(textValue, (width + valueWidth), textY);
-        width = width + valueWidth
+        width = width + (textValue.node().getComputedTextLength() + 12);
     }
 
     height = Math.max(height, 16) + 3;
